var levelState = {
	
	create: function() {
		
		//--------------------------------------------------------------------
		//                              SHOW FPS
		//--------------------------------------------------------------------
		if (showFPS) game.time.advancedTiming = true;
		
		//----------------------------------------------------------------------------
		//                              SPACE BACKGROUND
		//----------------------------------------------------------------------------
		stars = game.add.sprite(centerX, centerY - 50, "stars");
		stars.anchor.set(0.5);
		game.add.tween(stars).to({angle:360}, 17000, Phaser.Easing.Linear.None).start().repeat(-1);
		
		//------------------------------------------------------------------
		//                              PLANET
		//------------------------------------------------------------------
		planet = game.add.sprite(centerX, gameHeight+10, "planet");
		planet.anchor.setTo(0.5, 1);
		game.add.tween(planet).to({y:gameHeight+30}, 3000, Phaser.Easing.Sinusoidal.InOut).yoyo(true).start().repeat(-1);
		
		//-------------------------------------------------------------------------
		//                              BUTTON GROUPS
		//-------------------------------------------------------------------------
		levelButtons = game.add.group();
		levelButtons.x = 250;
		levelButtons.y = 308;
		bottomButtons = game.add.group();
		
		//-----------------------------------------------------------------------
		//                              LEFT BUTTON
		//-----------------------------------------------------------------------
		levelLeftButton = tweenButton(centerX - 114, 730, "levelLeftButton", function() {
			if (levelPage.frame > 0) {
				levelPage.frame -= 1;
				game.add.tween(levelButtons).to({x: 750}, 40, Phaser.Easing.Sinusoidal.In, true, 0).onComplete.add(function() {
					levelButtons.x = -250;
					setLevels(levelPage.frame);
					game.add.tween(levelButtons).to({x: 250}, 350, Phaser.Easing.Back.Out, true, 0);
				});
			}
		}, buttonClick);
		bottomButtons.add(levelLeftButton);
		
		//-----------------------------------------------------------------------
		//                              MENU BUTTON
		//-----------------------------------------------------------------------
		levelMenuButton = tweenButton(centerX, 730, "menuButton", function() { menuMusic.pause(); closeDoors("menuState"); }, buttonClick, 0.25);
		bottomButtons.add(levelMenuButton);
		
		//------------------------------------------------------------------------
		//                              RIGHT BUTTON
		//------------------------------------------------------------------------
		levelRightButton = tweenButton(centerX + 114, 730, "rightArrowButton", function() {
			if (levelPage.frame < 7) {
				levelPage.frame += 1;
				game.add.tween(levelButtons).to({x: -250}, 40, Phaser.Easing.Sinusoidal.In, true, 0).onComplete.add(function() {
					levelButtons.x = 750;
					setLevels(levelPage.frame);
					game.add.tween(levelButtons).to({x: 250}, 350, Phaser.Easing.Back.Out, true, 0);
				});
				
			}
		}, buttonClick);
		bottomButtons.add(levelRightButton);
		
		//--------------------------------------------------------------------------
		//                              PAGE INDICATOR
		//--------------------------------------------------------------------------
		levelPage = game.add.sprite(centerX, 622, "levelPage");
		levelPage.anchor.set(0.5);
		levelPage.scale.set(1.25);
		
		//------------------------------------------------------------------------
		//                              RESET BUTTON
		//------------------------------------------------------------------------
		resetDataButton = tweenButton(460, 756, "resetDataButton", function() {
			game.add.tween(resetDataButton.scale).to({x: 1.0,y: 1.0}, 40, Phaser.Easing.Linear.None).start();
			game.add.tween(resetDialog.scale).to({x: 1,y: 1}, 500, Phaser.Easing.Elastic.Out, true);
			levelButtons.setAll("input.enabled", false);
			bottomButtons.setAll("input.enabled", false);
		}, buttonClick, 0.15);
		bottomButtons.add(resetDataButton);
		
		//-------------------------------------------------------------------------
		//                              LEVEL BUTTONS
		//-------------------------------------------------------------------------
		
		for (var row = 0; row < 5; row++) {
			for (var column = 0; column < 4; column++) {
				
				var levelButton = tweenButton(column * 100 + 70 + 20 * column - 250, row * 100 + 70 + 19 * row - 308, "", function() {
					levelButtons.setAll("input.enabled", false);
					bottomButtons.setAll("input.enabled", false);
					playLevel = this.playLevel;
					menuMusic.stop();
					try {
						parent.cmgGameEvent("start", playLevel.toString());
					} catch(error) {
						// cmgGameEvent not present
					}
					closeDoors("playState");
				}, buttonClick, 0.5);
				
				levelButton.playLevel = 0;
				
				levelButton.image = game.add.sprite(0, 0, "levelButton");
				levelButton.image.anchor.set(0.5);
				levelButton.addChild(levelButton.image);
				
				levelButton.imageNext = game.add.sprite(0, 0, "levelButton");
				levelButton.imageNext.anchor.set(0.5);
				levelButton.imageNext.frame = 0;
				levelButton.imageNext.tween1 = game.add.tween(levelButton.imageNext).to({angle: 20}, 1500, Phaser.Easing.Sinusoidal.InOut, true).yoyo(true).repeat(-1);
				levelButton.imageNext.tween2 = game.add.tween(levelButton.imageNext.scale).to({x: 1.1, y: 1.1}, 450, Phaser.Easing.Sinusoidal.InOut, true).yoyo(true).repeat(-1);
				levelButton.addChild(levelButton.imageNext);
				
				levelButton.lock = game.add.sprite(-35, -35, "lock");
				levelButton.lock.anchor.set(0.5);
				levelButton.lock.scale.set(0.75);
				levelButton.addChild(levelButton.lock);
				
				levelButton.stars = game.add.sprite(-24, -44, "levelStars");
				levelButton.stars.anchor.set(0.5);
				levelButton.stars.scale.set(0.88);
				levelButton.addChild(levelButton.stars);
				
				levelButton.number1 = numberBlock(0, 0, "levelNumbers", 1, 0, 0);
				levelButton.addChild(levelButton.number1);
				levelButton.number10 = numberBlock(0, 0, "levelNumbers", 2, -7, 0);
				levelButton.addChild(levelButton.number10);
				levelButton.number100 = numberBlock(8, 0, "levelNumbers", 2, -7, 0);
				levelButton.addChild(levelButton.number100);
				levelButton.oneDigit = game.add.sprite(-27, 0, "levelNumbers");
				levelButton.oneDigit.anchor.set(0.5);
				levelButton.oneDigit.frame = 1;
				levelButton.addChild(levelButton.oneDigit);
				
				
				
				levelButton.set = function(playLevel) {
					this.playLevel = playLevel;
					this.image.exists = false;
					this.imageNext.exists = false;
					this.lock.exists = false;
					this.stars.exists = false;
					this.number1.exists = false;
					this.number10.exists = false;
					this.number100.exists = false;
					this.oneDigit.exists = false;
					
					if (levelStatus[playLevel-1] == -1) {
						this.image.exists = true;
						this.image.frame = 4;
						this.lock.exists = true;
						this.input.enabled = false;
					}
					if (levelStatus[playLevel-1] == 0) {
						this.imageNext.exists = true;
						this.input.enabled = true;
					}
					if (levelStatus[playLevel-1] > 0) {
						this.image.exists = true;
						this.image.frame = levelStatus[playLevel-1];
						this.stars.exists = true;
						this.stars.frame = levelStatus[playLevel-1];
						this.input.enabled = true;
					}
					
					if (playLevel < 10) {
						this.number1.exists = true;
						this.number1.set(playLevel);
					} else if (playLevel < 100) {
						this.number10.exists = true;
						this.number10.set(playLevel);
					} else {
						this.oneDigit.exists = true;
						this.number100.exists = true;
						this.number100.set(playLevel);
					}
					
				}
				
				levelButtons.add(levelButton);
				
			}
		}
		
		function setLevels(pageNumber) {
			for (var i = 0; i < 20; i++) {
				levelButtons.children[i].set(i+20*pageNumber+1);
			}
		}
		
		//------------------------------------------------------------------------
		//                              RESET DIALOG
		//------------------------------------------------------------------------
		resetDialog = game.add.sprite(centerX, centerY - 100, "resetDialog");
		resetDialog.anchor.set(0.5);
		
		//========== NO BUTTON ==========
		resetNoButton = tweenButton(-62, 95, "noButton", function() { 
			game.add.tween(resetDialog.scale).to({x: 0,y: 0}, 100, Phaser.Easing.Linear.None, true);
			levelButtons.setAll("input.enabled", true);
			bottomButtons.setAll("input.enabled", true);
		}, buttonClick, 0.25);
		resetDialog.addChild(resetNoButton);
		
		//========== YES BUTTON ==========
		resetYesButton = tweenButton(62, 95, "yesButton", function() { 
			for (var i = 0; i < 160; i++) {
				levelStatus[i] = -1;
			}
			levelStatus[0] = 0;
			saveData();
			unlockStatus = "ready";
			menuMusic.pause();
			closeDoors("levelState");
		}, buttonClick, 0.5);
		resetDialog.addChild(resetYesButton);
		
		resetDialog.scale.set(0);
		
		//------------------------------------------------------------------------
		//                              MOVE TO PAGE
		//------------------------------------------------------------------------
		bottomButtons.setAll("input.enabled", false);
		levelButtons.scale.set(0);
		levelButtons.alpha = 0;
		
		if (playLevel == 0 || levelStatus[159] < 1) {
			for (var page = 0; page < 8; page++) {
				if (levelStatus[159] < 1 && levelStatus[page * 20 + 19] > 0) {
					if (levelPage.frame < 7) {
						levelPage.frame += 1;
					}
				}
			}
		} else {
			levelPage.frame = parseInt((playLevel - 1)/20, 10);
		}
		
		setLevels(levelPage.frame);
		game.add.tween(levelButtons.scale).to({x: 1,y: 1}, 200, Phaser.Easing.Sinusoidal.Out, true, 200);
		game.add.tween(levelButtons).to({alpha: 1}, 200, Phaser.Easing.Sinusoidal.Out, true, 200).onComplete.add(function() { bottomButtons.setAll("input.enabled", true); });
		
		openDoors();
		
		//-----------------------------------------------------------------------
		//                              START MUSIC
		//-----------------------------------------------------------------------
		game.time.events.add(Phaser.Timer.SECOND * 0.5, function() {
			if (!musicIsMuted) {
				menuMusic.resume();
			};
		});
		
		//--------------------------------------------------------------------
		//                              SHOW FPS
		//--------------------------------------------------------------------
		if (showFPS) text = game.add.text(20, 750, "", {fill: "#CCCCCC", fontSize: 40});
		
	},
	
	
	update: function () {
		
		//-----------------------------------------------------------------------------
		//                              CHECK FOR UNLOCK
		//-----------------------------------------------------------------------------
		if (unlockStatus == "unlock") {
			makeAllLevelsAvailable();
			game.time.events.add(Phaser.Timer.SECOND * 0.50, function() {
				menuMusic.pause();
				closeDoors("levelState");
			});
		}
		
		//========== PRESS SPACE TO UNLOCK ALL LEVELS ==========
		if (allowEvaluate) {
			game.input.keyboard.addKey(Phaser.Keyboard.SPACEBAR).onDown.add(function() { unlockStatus = "unlock"; });
		}
		
		//--------------------------------------------------------------------
		//                              SHOW FPS
		//--------------------------------------------------------------------
		if (showFPS) text.setText(game.time.fps);
	
	}
	
}

unlockStatus = "wait";
levelStatus = new Array();

//----------------------------------------------------------------------------
//                              LOAD STORED DATA
//----------------------------------------------------------------------------
try {
	if (localStorage.getItem("ABlevelStatus1")) {
		for (var i = 0; i < 160; i++) {
			levelStatus[i] = parseInt(localStorage.getItem("ABlevelStatus" + i), 10);
		}
		//console.log("LOCAL STORAGE EXISTS: LOADING DATA");
	} else {
		for (var i = 0; i < 160; i++) {
			levelStatus[i] = -1;
		}
		levelStatus[0] = 0;
		saveData();
		//console.log("LOCAL STORAGE EXISTS: NO DATA");
	}
} catch(e) {
	for (var i = 0; i < 160; i++) {
		levelStatus[i] = -1;
	}
	levelStatus[0] = 0;
	//console.log("NO LOCAL STORAGE");
}

//----------------------------------------------------------------------------
//                              SAVE STORED DATA
//----------------------------------------------------------------------------
function saveData() {
	try {
		for (var i = 0; i < 160; i++) {
			localStorage.setItem("ABlevelStatus" + i, String(levelStatus[i]));
		}
		//console.log("DATA SAVED");
	} catch(e) {
		//console.log("NO SAVE");
	}
}

//-----------------------------------------------------------------------------
//                              UNLOCK ALL LEVELS
//-----------------------------------------------------------------------------
function unlockAllLevels() {
	if (unlockStatus == "ready") unlockStatus = "unlock";
}

function makeAllLevelsAvailable() {
	for (var i = 0; i < 159; i++) {
		if (levelStatus[i] < 1) levelStatus[i] = 1;
	}
	if (levelStatus[159] == -1) levelStatus[159] = 0;
	saveData();
	unlockStatus = "done";
}

function getRandomIntInclusive(min, max) {
	min = Math.ceil(min);
	max = Math.floor(max);
	return Math.floor(Math.random() * (max - min + 1)) + min;
}
